"""
========================================
  Introduction to Computer Programming
========================================

-----------------------------------------------
Read Evaluate Print Loop (REPL) example: high-low word-guessing game

demonstrating:
  REPLs
  top-down design
  built-in string slicing
  some built-in string methods
  open/reading/closing text files

Computer selects random word.
Player tries to guess it,
Each guess is either correct, or too "low" or "high" alphabetically.

--------------------

features that might improve the game:
   allow player to quit
   count guesses being made, enable losing
   handle case insensitivity
   remember the "low" and "high" words we have guessed so far
   more precise, more robust random-word selection
   provide more detailed instructions
   limit users guesses to actual words
"""


from random import randrange


WORD_FILE = 'wordle-words.txt'


def play_high_low_word_guess():
    display_instructions()
    long_string = read_words()
    hidden_word = choose_word(long_string)
    outcome = game_repl(hidden_word)
    wrap_up(outcome, hidden_word)


def display_instructions():
    print('I am thinking of a word.\n'
          'You goal is to try and guess it in as few guesses as possible.')


# returns one long string representing all possible words
# assumes WORD_FILE refers to a text file consisting of space separated words
def read_words():
    f = open(WORD_FILE)
    s = f.read()
    f.close()
    return s


# returns one word in string s, at random
def choose_word(s):
    r = randrange(len(s))
    word = extract(s, r)
    return word


# given a string and a start position in that string
# return next complete word in string from that position forward
# assumes there is exactly one space (' ') between each word
def extract(s, start):
    first_space = s.find(' ', start)
    next_space = s.find(' ', first_space + 1)
    word = s[first_space + 1 : next_space]
    return word


# REPL to try to guess word w
# returns True (you won), False (lost), None (quit)
def game_repl(w):
    status = None
    while status is None:
        guess = input('enter a guess... ')
        if guess == w:
            status = True
        elif guess < w:
            print('the word I am thinking of comes AFTER that')
        else:
            print('the word I am thinking of comes BEFORE that')
    return status


# prints a message based on result
def wrap_up(result, w):
    if result is None:
        print('You quit!')
    elif result:
        print('Well done!')
    else:
        print(f'You lose! The word was: "{w}".')


# uncomment to play game upon running the module
play_high_low_word_guess()
